package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.DeviceGroupMapper;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.MaliMapper;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IMaliTask;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.utils.ComonZipUtil;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SerializeUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/MaliService.class */
public class MaliService extends TaskBaseService implements IMaliTask {
    private Logger LOG = Logger.getLogger(HostService.class);
    private MaliMapper maliMapper = (MaliMapper) InstanceUtil.newDaoInstance(MaliMapper.class);
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private DeviceGroupMapper deviceGroupMapper = (DeviceGroupMapper) InstanceUtil.newDaoInstance(DeviceGroupMapper.class);

    @Transactional
    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        List<Map<String, Object>> devList = this.maliMapper.getTaskDevByTid(id);
        this.maliMapper.delTaskDevByTid(id);
        Integer rcount = Integer.valueOf(this.maliMapper.delete(id, version, DataRule.getRuleWhere(session, "t_task")));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        for (Map<String, Object> dev : devList) {
            Integer devid = ObjectUtil.getInt(dev.get("id"));
            this.maliMapper.delBugByDevId(devid);
            this.maliMapper.clearStatistics(devid);
        }
    }

    @Transactional
    public void insert(HttpSession session, String name, String desct, String devList, Integer val1, String ftpReportType) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("mali")) {
            throw new UEException("恶意代码任务未授权");
        }
        User u = (User) session.getAttribute("userInfo");
        Task task = new Task();
        task.setName(name);
        task.setDesct(desct);
        task.setUid(u.getId());
        task.setTaskType(7);
        task.setType(1);
        task.setAlarmType(0);
        task.setRule(DataRule.getRuleWhere(session, "t_task"));
        task.setVal1(val1);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        task.setFtpReportType(ftpReportType);
        List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(devList, new TypeReference<List<Map<String, Object>>>() { // from class: com.datacloudsec.scan.service.impl.MaliService.1
        });
        this.maliMapper.insert(task);
        for (Map<String, Object> devMap : devListMap) {
            Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(devMap.get("id")));
            if (map != null) {
                String ip = ObjectUtil.getString(map.get("ip"), "");
                if (StringUtils.isNotBlank(u.getIps()) && !IPUtil.ipVaild(ip, u.getIps())) {
                    throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                }
                Map<String, Object> devGroup = this.deviceGroupMapper.getDevGroupById(ObjectUtil.getInt(map.get("dgid")));
                map.put("devgroup", ObjectUtil.getString(devGroup.get("name"), ""));
                map.put("taskId", task.getId());
                map.put("type", 0);
                this.maliMapper.insertTaskDevice(map);
            } else {
                String ip2 = ObjectUtil.getString(devMap.get("url"), "");
                if (StringUtils.isNotBlank(u.getIps()) && !IPUtil.ipVaild(ip2, u.getIps())) {
                    throw new UEException("IP【" + ip2 + "】不在扫描范围内，可联系管理员授权扫描此IP");
                }
                Map<String, Object> newdev = new HashMap<>();
                newdev.put("type", 0);
                newdev.put("taskId", task.getId());
                newdev.put("name", ObjectUtil.getString(devMap.get("url"), ""));
                newdev.put("ip", ObjectUtil.getString(devMap.get("url"), ""));
                newdev.put("regionSid", Integer.valueOf(ObjectUtil.getInt(u.getRegionSid(), 110000)));
                newdev.put("regionCid", ObjectUtil.getInt(u.getRegionCid()));
                this.maliMapper.insertTaskDevice(newdev);
            }
        }
    }

    public void update(HttpSession session, Integer id, String name, String desct, Integer version, Integer val1, String ftpReportType) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        String rule = DataRule.getRuleWhere(session, "t_task");
        Task task = new Task();
        task.setId(id);
        task.setName(name);
        task.setDesct(desct);
        task.setUid(uid);
        task.setRule(rule);
        task.setVersion(version);
        task.setVal1(val1);
        task.setFtpReportType(ftpReportType);
        Integer rcount = this.maliMapper.update(task);
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    @Transactional
    public void delDev(Integer devId) throws Exception {
        this.maliMapper.delTaskDevById(devId);
        this.maliMapper.delBugByDevId(devId);
        this.maliMapper.clearStatistics(devId);
    }

    public void addDev(String devIds, Integer taskId) throws Exception {
        String[] devIdArr = devIds.split(",");
        for (String devid : devIdArr) {
            Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(devid));
            if (map != null) {
                map.put("taskId", taskId);
                map.put("type", 0);
                this.maliMapper.insertTaskDevice(map);
            }
        }
    }

    public List<Map<String, Object>> getDevDetailByTid(Integer id) throws Exception {
        return this.maliMapper.getDevDetailByTid(id);
    }

    public List<String> bugtimeForDevice(Integer id) {
        return this.maliMapper.bugtimeForDevice(id);
    }

    public List<Integer> maliForDevice(Integer id) {
        return this.maliMapper.maliForDevice(id);
    }

    public List<Map<String, Object>> bugPie(Integer id) throws Exception {
        return this.maliMapper.bugPie(id);
    }

    public Integer resultSearchCount(Integer id) throws Exception {
        return this.maliMapper.resultSearchCount(id);
    }

    public List<Map<String, Object>> resultSearch(Integer id, Integer offset, Integer limit) throws Exception {
        return this.maliMapper.resultSearch(id, offset, limit);
    }

    public int markBugErr(Integer id, Integer status) throws Exception {
        return this.maliMapper.markBugErr(id, status);
    }

    public void manualAddMali(HttpSession session, String ip, Integer taskId) throws Exception {
        User user = (User) session.getAttribute("userInfo");
        Map<String, Object> web = new HashMap<>();
        web.put("name", ip);
        web.put("ip", ip);
        web.put("type", 0);
        web.put("taskId", taskId);
        web.put("regionCid", user.getRegionCid());
        web.put("regionSid", Integer.valueOf(user.getRegionSid() == null ? 110000 : user.getRegionSid().intValue()));
        this.maliMapper.insertTaskDevice(web);
    }

    public File maliBackup(Task t) throws Exception {
        File dir = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File f = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        try {
            SerializeUtil.serializeObj(new File(dir, "task.backup"), t);
            List<Map<String, Object>> devList = this.maliMapper.getTaskDevByTid(t.getId());
            for (Map<String, Object> dev : devList) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                File devDir = new File(dir, new StringBuilder().append(devid).toString());
                if (!devDir.exists()) {
                    devDir.mkdirs();
                }
                SerializeUtil.serializeObj(new File(devDir, "dev.backup"), dev);
                SerializeUtil.serializeObj(new File(devDir, "bug.backup"), this.maliMapper.getBugByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "sta.backup"), this.maliMapper.getStaByDevId(devid));
            }
            ComonZipUtil.zip(dir.getPath(), f.getPath());
            if (dir != null && dir.exists()) {
                FileUtils.deleteDirectory(dir);
            }
            return f;
        } catch (Exception e) {
            throw e;
        }
    }

    @Transactional
    public void maliRestore(HttpSession session, File f) throws Exception {
        File unzipFile = new File(Constant.COMMON_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        ComonZipUtil.unzip(f, unzipFile);
        File taskFile = new File(unzipFile, "task.backup");
        Task t = (Task) SerializeUtil.deserializeObj(taskFile);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.maliMapper.getTaskCountByName(t.getName(), 7, uid, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("maliTaskAlready:" + unzipFile.getName());
        }
        try {
            restore(unzipFile, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(unzipFile);
            throw e;
        }
    }

    private void restore(File unzipFile, Task t) throws Exception {
        Map<String, Object> device;
        if (unzipFile == null || t == null) {
            return;
        }
        this.maliMapper.insert(t);
        for (File taskDir : unzipFile.listFiles()) {
            if (!taskDir.getName().equals("task.backup") && (device = (Map) SerializeUtil.deserializeObj(new File(taskDir, "dev.backup"))) != null && device.size() != 0) {
                device.put("taskId", t.getId());
                this.maliMapper.inserTaskDevById(device);
                Integer devId = ObjectUtil.getInt(device.get("id"));
                List<Map<String, Object>> bugs = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug.backup"));
                if (bugs != null && bugs.size() > 0) {
                    this.maliMapper.insertMaliRes(devId, bugs);
                }
                List<Map<String, Object>> stas = (List) SerializeUtil.deserializeObj(new File(taskDir, "sta.backup"));
                if (stas != null && stas.size() > 0) {
                    this.maliMapper.insertMaliSta(devId, stas);
                }
            }
        }
        startTimer(t.getId(), t.getType(), t.getPeriodTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime());
        FileUtils.deleteDirectory(unzipFile);
    }

    @Transactional
    public void maliEnter(HttpSession session, String filename) throws Exception {
        File f = new File(Constant.COMMON_DIR, filename);
        if (f == null || !f.exists()) {
            this.LOG.error("网站恶意代码恢复，文件不存在！");
            return;
        }
        User u = (User) session.getAttribute("userInfo");
        Task t = (Task) SerializeUtil.deserializeObj(new File(f, "task.backup"));
        t.setName(String.valueOf(t.getName()) + System.nanoTime());
        t.setUid(u.getId());
        try {
            restore(f, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(f);
            throw e;
        }
    }
}
